@@ -1,5 +1,11 @@
 from Products.Five import BrowserView
 from Products.CMFCore.utils import getToolByName
+try:
+    from collective.flowplayer.interfaces import IFlowPlayable
+    FLOWPLAYER_EXISTS = True
+except ImportError:
+    FLOWPLAYER_EXISTS = False
+
 
 class GetMediaShowItemView(BrowserView):
     """ Class that extracts relevant information for the slideshow
@@ -29,7 +35,6 @@ class GetMediaShowItemView(BrowserView):
         title = self.sanitizeStringForJson(title)    
         description = self.sanitizeStringForJson(description)
         
-        #print(description)
             
         jsonStr = '{"title": "'+title+'", "description": "'+description+'", "type": "'+type+'", "media": {"url": "'+media+'", "type" : "'+mediaType+'"}}'
         if callback is not None:
@@ -44,14 +49,20 @@ class GetMediaShowItemView(BrowserView):
     def getMediaURL(self):
         """ finds and returns relevant leading media for the context item
         """
-        item = self.context     
+        item = self.context
+        
+        if(self.isVideo(item)):
+            return item.absolute_url()
+        
+        if item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
+            return item.remoteUrl
         
         catalog = getToolByName(self.context, 'portal_catalog')
         plone_utils = getToolByName(self.context, 'plone_utils')
         path = '/'.join(item.getPhysicalPath())
         
         if plone_utils.isStructuralFolder(item):
-            results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = 'Image', sort_on = 'getObjPositionInParent')
+            results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = ['Image', 'File'], sort_on = 'getObjPositionInParent')
             if len(results) > 0:
                 leadMedia = results[0]
                 if leadMedia.portal_type == 'Image':
@@ -65,9 +76,22 @@ class GetMediaShowItemView(BrowserView):
             return ""
         
     def getMediaType(self):
-        """ Finds and returns the type of lead image
+        """ Finds and returns the type of lead media
         """
-        return "Image"
+        item = self.context
+        if(self.isVideo(item)):
+            return "Video"
+        elif item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
+            return "Youtube"
+        else:
+            return "Image"
+    
+    def isVideo(self, item):
+        if FLOWPLAYER_EXISTS:
+            result = IFlowPlayable.providedBy(item)
+        else:
+            result = False
+        return result
     
     
 class MediaShowListingView(BrowserView):
@@ -110,21 +134,35 @@ class MediaShowListingView(BrowserView):
     def getMediaURL(self, item):
         """ finds and returns relevant leading media for the given item
         """    
-        
+        if(self.isVideo(item)):
+            return item.absolute_url()
+            
+        if item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
+            return item.remoteUrl
+            
         catalog = getToolByName(self.context, 'portal_catalog')
         plone_utils = getToolByName(self.context, 'plone_utils')
         path = '/'.join(item.getPhysicalPath())
         
         if plone_utils.isStructuralFolder(item):
-            results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = 'Image', sort_on = 'getObjPositionInParent')
+            results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = ['Image', 'File', 'Link'], sort_on = 'getObjPositionInParent')
             if len(results) > 0:
                 leadMedia = results[0]
                 if leadMedia.portal_type == 'Image':
                     return leadMedia.getURL() + '/image_large'
+                elif leadMedia.portal_type == 'Link':
+                    return leadMedia.remoteUrl
                 else:
                     return leadMedia.getURL()
             else:
                 return ""
         else:
             #TODO: Add lead image support and News Item Image support
-            return ""
\ No newline at end of file
+            return ""
+        
+    def isVideo(self, item):
+        if FLOWPLAYER_EXISTS:
+            result = IFlowPlayable.providedBy(item)
+        else:
+            result = False
+        return result
\ No newline at end of file
